@@ -1,6 +1,6 @@
 /* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: CgiEnvironment.cpp,v 1.29 2014/06/11 04:43:46 sebdiaz Exp $
+ *  $Id: CgiEnvironment.cpp,v 1.30 2014/12/07 14:33:02 sebdiaz Exp $
  *
  *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
  *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
@@ -71,7 +71,7 @@ cgicc::CgiEnvironment::CgiEnvironment(CgiInput *input)
     
     if(getenv("CGICC_MAX_CONTENTLENGTH")&&getContentLength()>(long unsigned int)atoi(getenv("CGICC_MAX_CONTENTLENGTH")))
     {
-      exit(1);
+        throw std::runtime_error("Malformed input");
     }
     else
     // If input is 0, use the default implementation of CgiInput
